/*
 * Turbo Cable Utilities
 *
 * Copyright (C) 2004 BLADOX, s.r.o.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 */


#ifndef __CABLE_LIB_H_
#define __CABLE_LIB_H_

/** unsigned 1byte=8bits */
typedef unsigned char u8;
/** unsigned 2bytes=16bits */
typedef unsigned short u16;
/** unsigned 4bytes=32bits */
typedef unsigned long u32;
/** unsigned 8bytes=64bits */
typedef unsigned long long u64;

typedef char b8;
typedef short b16;
typedef long b32;
typedef long long b64;


#include <cable.h>
#include <err.h>

void set_verbose();
void set_baudrate(int baudrate);

#define SORT_APPEND             0x00
#define SORT_SMS                0x01
#define SORT_SMS_SKIP_2         0x02
#define SORT                    0x03

#define LOAD32L(x, y) \
{ x = ((u32)((y)[3] & 255)<<24) | \
	((u32)((y)[2] & 255)<<16) | \
		((u32)((y)[1] & 255)<<8)  | \
		((u32)((y)[0] & 255)); }

#define STORE32L(x, y) \
{ (y)[3] = (u8)(((x)>>24)&255); (y)[2] = (u8)(((x)>>16)&255);   \
	(y)[1] = (u8)(((x)>>8)&255); (y)[0] = (u8)((x)&255); }


#define LOAD32H(x, y) \
{ x = ((unsigned long)((y)[0] & 255)<<24) | \
	        ((unsigned long)((y)[1] & 255)<<16) | \
			                ((unsigned long)((y)[2] & 255)<<8)  | \
					                ((unsigned long)((y)[3] & 255)); }


u8  fs_ino_index(u32 fp);
u16 fs_ino_block(u32 desc);
u32 fs_ino_p(u16 block, u8 index);

//CABLE SPECIFIC FNCS



//CABLE_UPLOAD_APP:
u8 app_open();
u8 app_append(u8 * data, u16 pos, u8 l);
u8 app_close(u8 * name);

b32 create_file(u8 * path, u8 * name, u8 *ext, u8 srt);
u8 file_append(u32 f, u8 * data, u16 pos, u8 l);

b32 create_dir(u8 * path, u8 * name, u8 srt);

void format_df();

b32 find_file(u8 * path, u8 * name, u32 *len, u32 *len_raw);
u8 file_read(u32 f, u8 * data, u32 pos, u8 l);

u8 detect_mc(u32 *root, u8 *df_id, u8 *df_blocks, u16 * df_pages);
u8 block_read(u8 * data, u16 block, u8 pos, u8 l);

void cable_delete_inode(u32 f);
void cable_clear_apps();

	

#endif
