/*
 * Turbo Cable Utilities
 *
 * Copyright (C) 2004 BLADOX, s.r.o.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 */

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <time.h>
#include <stdarg.h>
#include "modeminit.h"
#include "logging.h"
#include "alarm.h"

#include "cablelib.h"

/*
TODO:
error handling
*/

u8 overwrite;
u8 sort;

void help ()
{
  printf ("Usage: [args] application_file\n");
  printf ("-bx\tbaudrate x (def. 19200)\n");
  printf ("-dx\tdevice x (def. /dev/ttyS1)\n");
  printf ("-h\thelp\n");
  printf ("-v\tverbose\n");
  exit (0);
}

int main (int argc, char **argv)
{
  char cmd[500];
  char answer[1000];
  u8 buf[500];
  u8 t[] = { 0x01, 0x23, 0x45, 0x67 };
  u32 i, j;
  u8 f;
  int result;
  struct stat _st;
  FILE *fs;
  u8 *s_name;
  u8 *d_name;
  int s_size;
  u8 *s_buf;
  int ret;
  int pos;
  int len;
  u8 ext[] = { 0, 0, 0, 0 };
  u8 path[1000] = { '/', '\0' };
  u8 name[1000];
  u16 name_end;
  u16 path_end;

  strcpy (device, "/dev/ttyS1");
  rtscts = 1;
  overwrite = 0;
  sort = SORT;

  do
  {
    result = getopt (argc, argv, "vs:od:b:h");
//    printf("RES %c %d\n",result, result);
    switch (result)
    {
      case 'H':
	rtscts = 0;
	break;
      case 'd':
	strcpy (device, optarg);
	break;
      case 'b':
	set_baudrate (atoi (optarg));
	break;
      case 'v':
	set_verbose ();
	break;
      case 'h':
	help ();
	break;
    }
  }
  while (result > 0);

  if (argc - optind != 1)
    help ();
  s_name = argv[optind++];
  printf ("SRC %s\n", s_name); fflush(stdout);
  ret = stat (s_name, &_st);
  if (ret < 0)
  {
    printf ("Cannot stat %s\n", s_name);
    exit (1);
  }
  printf ("SIZE %d\n", _st.st_size); fflush(stdout);
  s_size = _st.st_size;
  s_buf = malloc (s_size);

#ifndef WIN32_MINGW
  fs = fopen (s_name, "r");
  for (i = 0; i < s_size; i++)
    s_buf[i] = fgetc (fs);
  fclose (fs);
#else
{
HANDLE * f1;
int n_in;

f1=CreateFile(s_name, GENERIC_READ, 0, NULL, OPEN_EXISTING, 0, NULL);

if(f1==INVALID_HANDLE_VALUE)
{
printf("Cannot open file %s (error %d)\n", s_name, GetLastError());
exit(-1);
}

ReadFile(f1, s_buf, s_size, (DWORD*)(&n_in), NULL);

CloseHandle(f1);
}
#endif

  openmodem ();
  setmodemparams ();
  initmodem ();
  printf ("modem initiated\n"); fflush(stdout);

  f = app_open ();
  if (f)
    goto E_RR;

  pos = 0;

  while (pos < s_size)
  {
    len = s_size - pos;
    if (len > 128)
      len = 128;
    f = app_append (s_buf, pos, len);
    if (f)
      goto E_RR;
    pos += 128;
  }

  f = app_close (s_name);
  if (f)
    goto E_RR;
  return;

E_RR:
  printf ("ERROR %d\n", f);

/*

- no memory for flashing
- no slot
- no progmem 
- no ram
- apps locked
- wrong crc 
*/

}
