/*
 * Turbo Cable Utilities
 *
 * Copyright (C) 2004 BLADOX, s.r.o.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 */


#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <time.h>
#include <stdarg.h>
#include "modeminit.h"
#include "logging.h"
#include "alarm.h"
#include "cablelib.h"

/*
TODO:
overwrite
if path doesnot exists
error handling
*/

u8 overwrite;
u8 sort;

void help ()
{
  printf ("Usage: [args] src_file dst_file\n");
  printf ("-bx\tbaudrate x (def. 19200)\n");
  printf ("-dx\tdevice x (def. /dev/ttyS1)\n");
  printf ("-h\thelp\n");
  printf ("-o\toverwrite if exists\n");
  printf ("-sx\tsort x (0=append, 1=sms, 2=sms_skip_2, 3=sort)\n");
  printf ("-v\tverbose\n");
  exit (0);
}

int main (int argc, char **argv)
{
  char cmd[500];
  char answer[1000];
  u8 buf[500];
  u8 t[] = { 0x01, 0x23, 0x45, 0x67 };
  u32 i, j;
  b32 f;
  int result;
  struct stat _st;
  FILE *fs;
  u8 *s_name;
  u8 *d_name;
  int s_size;
  u8 *s_buf;
  int ret;
  int pos;
  int len;
  u8 ext[] = { 0, 0, 0, 0 };
  u8 path[1000] = { '/', '\0' };
  u8 name[1000];
  u16 name_end;
  u16 path_end;

  strcpy (device, "/dev/ttyS1");
  rtscts = 1;
  overwrite = 0;
  sort = SORT;

  do
  {
    result = getopt (argc, argv, "vs:od:b:h");
    switch (result)
    {
      case 'H':
	rtscts = 0;
	break;
      case 'd':
	strcpy (device, optarg);
	break;
      case 'b':
	set_baudrate (atoi (optarg));
	break;
      case 'v':
	set_verbose ();
	break;
      case 's':
	sort = atoi (optarg);
	break;
      case 'o':
	overwrite = 1;
	break;
      case 'h':
	help ();
	break;
    }
  }
  while (result > 0);

  if (argc - optind != 2)
    help ();
  s_name = argv[optind++];
  d_name = argv[optind++];
  printf ("SRC %s\n", s_name);
  printf ("DST %s\n", d_name);
  ret = stat (s_name, &_st);
  if (ret < 0)
  {
    printf ("Cannot stat %s\n", s_name);
    exit (1);
  }
  printf ("SIZE %d\n", _st.st_size);
  s_size = _st.st_size;
  s_buf = malloc (s_size);

#ifndef WIN32_MINGW
  fs = fopen (s_name, "r");
  for (i = 0; i < s_size; i++)
    s_buf[i] = fgetc (fs);
  fclose (fs);
#else
{
HANDLE * f1;
int n_in;

f1=CreateFile(s_name, GENERIC_READ, 0, NULL, OPEN_EXISTING, 0, NULL);

if(f1==INVALID_HANDLE_VALUE)
{
printf("Cannot open file %s (error %d)\n", s_name, GetLastError());
exit(-1);
}

ReadFile(f1, s_buf, s_size, (DWORD*)(&n_in), NULL);

CloseHandle(f1);
}
#endif

  len = strlen (d_name);
  for (i = len; i > 0; i--)
    if (d_name[i - 1] == '.')
      break;

  name_end = i;
  if (i != 0)
  {
    len = len - i;
    if (len > 3)
      len = 3;
    for (j = 0; j < len; j++)
      ext[j] = d_name[i + j];
    name_end--;
  }
  else
    name_end = strlen (d_name);

  for (i = name_end; i > 0; i--)
    if (d_name[i - 1] == '/')
      break;
  path_end = i;

  len = strlen (d_name);
  for (j = 0; j < name_end - path_end; j++)
    name[j] = d_name[i + j];
  name[j] = '\0';

  for (j = 0; j < path_end; j++)
    path[j] = d_name[j];

  printf ("EXT %s\n", ext);
  printf ("NAME %s\n", name);
  printf ("PATH %s\n", path);

  openmodem ();
  setmodemparams ();
  initmodem ();
  printf ("modem initiated\n");

  f = create_file (path, name, ext, sort);

  pos = 0;

  while (pos < s_size)
  {
    len = s_size - pos;
    if (len > 128)
      len = 128;
    file_append (f, s_buf, pos, len);
    pos += 128;
  }

}
