/*
 * Turbo Cable Utilities
 *
 * Copyright (C) 2004 BLADOX, s.r.o.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 */


#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <time.h>
#include <stdarg.h>
#include "modeminit.h"
#include "logging.h"
#include "alarm.h"

#include "cablelib.h"

/*
TODO:
overwrite
if path doesnot exists
error handling
*/

u8 overwrite;
u8 sort;

u16 from_block;
u16 count_block;

void help ()
{
  printf ("Usage: [args] dst_file\n");
  printf ("-bx\tbaudrate x (def. 19200)\n");
  printf ("-dx\tdevice x (def. /dev/ttyS1)\n");
  printf ("-f\tfrom_block (def. 0)\n");
  printf ("-c\tcount_blocks (def. 0=all)\n");
  printf ("-h\thelp\n");
  printf ("-v\tverbose\n");
  exit (0);
}

int main (int argc, char **argv)
{
  char cmd[500];
  char answer[1000];
  u8 buf[500];
  u8 t[] = { 0x01, 0x23, 0x45, 0x67 };
  u32 i, j;
  b32 f;
  int result;
  struct stat _st;
  FILE *fs;
  u8 *s_name;
  u8 *d_name;
  int s_size;
  u8 *s_buf;
  int ret;
  int pos;
  int len;
  u8 ext[] = { 0, 0, 0, 0 };
  u8 path[1000] = { '/', '\0' };
  u8 name[1000];
  u16 name_end;
  u16 path_end;
  u32 f_len;
  u32 f_len_raw;
  u32 root;
  u8 df_id;
  u8 df_blocks;
  u16 df_pages;
  u8 mc_status;
  u16 nr_blocks;

#define MC_OK                   0x00
#define MC_NOT_PRESENT          0x01
#define MC_NOT_READY            0x02

  strcpy (device, "/dev/ttyS1");
  rtscts = 1;
  overwrite = 0;
  from_block = 0;
  count_block = 0;
  sort = SORT;

  do
  {
    result = getopt (argc, argv, "vs:od:b:h:f:c:");
    switch (result)
    {
      case 'H':
	rtscts = 0;
	break;
      case 'd':
	strcpy (device, optarg);
	break;
      case 'b':
	set_baudrate (atoi (optarg));
	break;
      case 'c':
	count_block = atoi (optarg);
	break;
      case 'f':
	from_block = atoi (optarg);
	break;
      case 'v':
	set_verbose ();
	break;
      case 'h':
	help ();
	break;
    }
  }
  while (result > 0);

  if (argc - optind != 1)
    help ();
  d_name = argv[optind++];
  printf ("DST %s\n", d_name);

  name_end = strlen (d_name);
  openmodem ();
  setmodemparams ();
  initmodem ();
  printf ("modem initiated\n");

  mc_status = detect_mc (&root, &df_id, &df_blocks, &df_pages);
  if (mc_status != MC_OK)
  {
    printf ("DF not ready\n");
    exit (1);
  }
  printf ("DF_ID: %02X #blocks %02X #pages %d\n", df_id, df_blocks, df_pages);
  nr_blocks = df_blocks * df_pages;
  if (count_block == 0)
    count_block = nr_blocks;
  if (from_block > nr_blocks)
  {
    printf ("FROM_BLOCK > #blocks\n");
    exit (1);
  }
  if (count_block + from_block > nr_blocks)
  {
    count_block = nr_blocks - from_block;
  }
  pos = 0;
  fs = fopen (d_name, "w+");
//fputc card, start, count
  for (i = from_block; i < count_block + from_block; i++)
  {
    block_read (buf, i, 0, 132);
    block_read (&buf[132], i, 132, 132);

    printf ("BLOCK: %d\n", i);
    for (j = 0; j < 264; j++)
    {
      fputc (buf[j], fs);
      if (j % 16 == 0)
	printf ("\n");
      printf ("%02X ", buf[j]);
    }
    printf ("\n");
    LOAD32H (f, &buf[264 - 4]);
    if (i % df_blocks == df_blocks - 1)
      printf ("NR_BURNS: %u\n", f);
  }
  fclose (fs);
}
